@@ -28,7 +28,7 @@ from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 import wave
 
-VERSION = u'2022.05-1'
+VERSION = u'8.3.0'
 
 class audio_low_latency_play(item):
 
@@ -239,11 +239,6 @@ class audio_low_latency_play(item):
                 self.clock.sleep(delay)
                 self.show_message(u'Delay done')
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.start()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.start_stream()
-
         start_time = self.set_stimulus_onset()
 
         self.show_message(u'Starting audio playback')
@@ -277,11 +272,6 @@ class audio_low_latency_play(item):
                     self.show_message(u'Audio stopped, duration exceeded')
                     break
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.stop()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.stop_stream()
-
         self.set_stimulus_offset()
 
         wav_file.close()
@@ -297,11 +287,6 @@ class audio_low_latency_play(item):
                 self.clock.sleep(delay)
                 self.show_message(u'Delay done')
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.start()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.start_stream()
-
         start_time = self.set_stimulus_onset()
 
         self.show_message(u'Starting audio playback')
@@ -332,11 +317,6 @@ class audio_low_latency_play(item):
                     self.show_message(u'Audio stopped, duration exceeded')
                     break
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.stop()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.stop_stream()
-
         self.set_stimulus_offset()
 
         self.show_message(u'Finished audio playback')
