@@ -28,7 +28,7 @@ from libqtopensesame.items.qtautoplugin import qtautoplugin
 from libopensesame.exceptions import osexception
 import pygame
 
-VERSION = u'2022.05-1'
+VERSION = u'8.3.0'
 
 class audio_low_latency_play_init(item):
 
@@ -321,6 +321,8 @@ class audio_low_latency_play_init(item):
                     raise osexception(
                         u'Could not start audio device', exception=e)
 
+                self.device.start()
+
             elif self.module == self.experiment.oss4_module_name:
                 import ossaudiodev
                 self.device = ossaudiodev.open('w')
@@ -394,6 +396,7 @@ class audio_low_latency_play_init(item):
             self.show_message(u"Closing audio device")
             self.device.close()
             if  self.module == self.pyaudio_module_name:
+                self.device.stop_stream()
                 self.device.close()
                 self.device_init.terminate()
             self.device = None
