@@ -29,7 +29,7 @@ from openexp.keyboard import keyboard
 import threading
 import wave
 
-VERSION = u'2022.05-1'
+VERSION = u'8.3.0'
 
 class audio_low_latency_play_start(item):
 
@@ -251,11 +251,6 @@ class audio_low_latency_play_start(item):
                 self.clock.sleep(delay)
                 self.show_message(u'Delay done')
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.start()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.start_stream()
-
         start_time = self.set_stimulus_onset()
 
         self.show_message(u'Starting audio playback')
@@ -283,11 +278,6 @@ class audio_low_latency_play_start(item):
                     self.show_message(u'Audio playback stopped, duration exceeded')
                     break
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.stop()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.stop_stream()
-
         self.set_stimulus_offset()
 
         wav_file.close()
@@ -306,11 +296,6 @@ class audio_low_latency_play_start(item):
                 self.clock.sleep(delay)
                 self.show_message(u'Delay done')
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.start()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.start_stream()
-
         start_time = self.set_stimulus_onset()
 
         self.show_message(u'Starting audio playback')
@@ -335,11 +320,6 @@ class audio_low_latency_play_start(item):
                     self.show_message(u'Audio stopped, duration exceeded')
                     break
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.stop()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.stop_stream()
-
         self.set_stimulus_offset()
 
         self.show_message(u'Finished audio playback')
