@@ -28,8 +28,9 @@ from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 import threading
 import wave
+import numpy
 
-VERSION = u'2022.05-1'
+VERSION = u'8.3.0'
 
 class audio_low_latency_record_start(item):
 
@@ -239,11 +240,6 @@ class audio_low_latency_record_start(item):
                 self.clock.sleep(delay_start)
                 self.show_message(u'Delay done')
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.start()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.start_stream()
-
         start_time = self.set_stimulus_onset()
 
         while True:
@@ -275,13 +271,9 @@ class audio_low_latency_record_start(item):
         self.set_stimulus_offset()
 
         if self.ram_cache == u'yes':
+            self.show_message(u'Writing data to wav file')
             wav_file.writeframes(b''.join(frames))
 
-        if self.module == self.experiment.sounddevice_module_name:
-            stream.stop()
-        elif self.module == self.experiment.pyaudio_module_name:
-            stream.stop_stream()
-
         wav_file.close()
 
         self.show_message(u'Finished audio recording')
@@ -298,6 +290,8 @@ class audio_low_latency_record_start(item):
             l, data = stream.read()
         else:
             data = stream.read(chunk)
+            if self.module == self.experiment.sounddevice_module_name:
+                data = numpy.frombuffer(data[0])
 
         # save data to file/ram
         if self.ram_cache == u'yes':
